@@ -15,16 +15,16 @@ import classeval.ROC as ROC
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 # module level doc-string
 __doc__ = """
 classeval
-=====================================================================
+=============================
 
 Description
 -----------
-classeval is a python package that contains functionalities and plots for fast and easy classifier evaluation.
+classeval is a python package for fast and easy classifier evaluation.
 
 
 Example
@@ -48,6 +48,7 @@ Example
 
 References
 ----------
+* https://erdogant.github.io/classeval
 * https://github.com/erdogant/classeval
 * https://scikit-learn.org/stable/modules/model_evaluation.html#scoring-parameter
 * http://arogozhnikov.github.io/2015/10/05/roc-curve.html
